html{
    overflow: auto;
}
body {
    background-color: rgb(247, 247, 247);
    font-family: system-ui, -apple-system, "Segoe UI", Roboto;
}

tr:hover {
    background-color: rgb(230, 229, 229);
}

img {
    height: 40px;
}

img:hover {
    cursor: pointer;
}

.add-button{
    cursor: pointer;
    padding-top: 10px;
    padding-bottom: 10px;
    padding-left: 15px;
    padding-right: 15px;
    border-radius: 5px;
    color: white;
    background-color: #0084ff;
    border: none;

}
.page-item.disabled{
    cursor: default;

}
td{
    padding: 5px;
}
#search_button{
    display: flex;
    justify-content: center;
    align-items: center;
    background-color: #0084ff;
    width: 35px;
    height: 35px;
    display: block;
    border: none;
    border-top-right-radius: 5px;
    border-bottom-right-radius: 5px;
}

.littlebutton{
    border: none;
    background: none;
    background-color: none;
}

.littleicons{
    height: 16px;
    width:  16px;
}

.dropbtn {
    background-color: #3498DB;
    color: white;
    padding: 8px;
    font-size: 16px;
    border: none;
    cursor: pointer;
  }
  
  .dropbtn:hover, .dropbtn:focus {
    background-color: #2980B9;
  }
  
  .dropdown {
    position: relative;
    display: inline-block;
  }
  
  .dropdown-content {
    display: none;
    position: absolute;
    background-color: #f1f1f1;
    min-width: 160px;
    overflow: auto;
    box-shadow: 0px 8px 16px 0px rgba(0,0,0,0.2);
    z-index: 1;
  }
  
  .dropdown-content.show {
    color: black;
    padding: 12px 16px;
    text-decoration: none;
    display: block;
    list-style-type: none;
  }
  
  .dropdown a:hover {background-color: #ddd;}
/* 
  #dropDownList{
    
  } */
  .page-link{
    color: black;
    padding: 10px;
  }
  .page-link:active{
    border-style: none;
    outline: none;
    pointer-events: fill;
  }
  .page-link.current{
    padding: 10px;
    background-color: #0084ff;
    color: white;
    border: 1px #0084ff solid;
}
.Pagination-Nav{
    margin-top: 35px;
    padding-left: 5px;
    padding-right: 40px;
    list-style-type: none;
    display: flex;
    justify-content: center;
}
.page-link.disable{
    cursor: default;
    pointer-events: none;
}
.modal {
    display: none; /* Hidden by default */
    position: fixed; /* Stay in place */
    z-index: 1; /* Sit on top */
    left: 0;
    top: 0;
    width: 100%; /* Full width */
    height: 100%; /* Full height */
    overflow: auto; /* Enable scroll if needed */
    background-color: rgb(0,0,0); /* Fallback color */
    background-color: rgba(0,0,0,0.4); /* Black w/ opacity */
  }
  
  /* Modal Content/Box */
  .modal-content {
    border-radius: 10px;
    background-color: #fefefe;
    margin: 15% auto; /* 15% from the top and centered */
    padding-left: 15px;
    padding-right: 15px;
    border: 1px solid #888;
    width: 15%; /* Could be more or less, depending on screen size */
  }
  
  /* The Close Button */
  .close {
    color: #aaa;
    float: right;
    font-size: 28px;
    font-weight: bold;
  }
  
  .close:hover,
  .close:focus {
    color: black;
    text-decoration: none;
    cursor: pointer;
  }
#ButtonsDiv{
    margin-top: 15px;
    padding-bottom: 10px;
    display: flex;
    /* justify-content: space-around; */
    gap:15px;
}
.modal-buttons{

    padding: 5px;
    cursor: pointer;
    color: white;
    border-radius: 5px;
    border: none;
    background-color: #0084ff;

}